<?php

namespace SuperRhino\Utils\Counter;

use SuperRhino\Utils\Redis\Redis;

class RedisCounterAdapter implements CounterInterface {

    /**
     * @var \Redis
     */
    protected $redis;

    public function __construct() {
        $this->redis = Redis::getRedis();
    }

    protected function getKey(string $name, string $key) {
        return 'cnt:' . $name . ':' . $key;
    }

    public function existsRow(string $name, string $key): bool {
        return $this->redis->exists($this->getKey($name, $key));
    }

    public function existsColumn(string $name, string $key, string $column): bool {
        return $this->redis->hexists($this->getKey($name, $key), $column);
    }

    public function setRow(string $name, string $key, array $row): bool {
        return $this->redis->hmset($this->getKey($name, $key), $row);
    }

    public function setColumn(string $name, string $key, string $column, int $count, bool $NX = false): bool {
        if ($NX) {
            return $this->redis->hSetNx($this->getKey($name, $key), $column, $count);
        }
        $this->redis->hset($this->getKey($name, $key), $column, $count);
        return true;
    }

    public function getRow(string $name, string $key): array {
        return $this->redis->hgetall($this->getKey($name, $key));
    }

    public function getColumn(string $name, string $key, string $column): int {
        return (int)$this->redis->hget($this->getKey($name, $key), $column);
    }

    public function increment(string $name, string $key, string $column, int $increment = 1): int {
        return $this->redis->hincrby($this->getKey($name, $key), $column, $increment);
    }

    public function resetRow(string $name, string $key): bool {
        return $this->redis->del($this->getKey($name, $key)) > 0;
    }

    public function resetColumn(string $name, string $key, string $column): bool {
        return $this->redis->hdel($this->getKey($name, $key), $column) > 0;
    }


}